@@ -96,7 +96,7 @@ intersphinx_mapping = {
     "python": ("https://docs.python.org/3/", None),
     "h5py": ("https://docs.h5py.org/en/stable/", None),
     "cerberus": ("https://docs.python-cerberus.org/en/stable/", None),
-    "scipy": ("https://docs.scipy.org/doc/scipy/reference/", None)
+    "scipy": ("https://docs.scipy.org/doc/scipy-1.8.0/html-scipyorg/", None)
     # "pandas": ("https://pandas.pydata.org/pandas-docs/stable/", None),
     # "numpy": ("https://docs.scipy.org/doc/numpy/", None),
     # "numba": ("https://numba.pydata.org/numba-doc/latest/", None),
