@@ -5,7 +5,7 @@ import re
 import glob
 from pathlib import Path
 
-import toml
+import tomli
 import cerberus
 
 from .utils import ChainedKeyMap, natural_sort_key
@@ -256,8 +256,9 @@ class Profile(ChainedKeyMap):
         self._violations = []
 
         try:
-            content = toml.load(self.path)
-        except (toml.TomlDecodeError, UnicodeDecodeError) as error:
+            with self.path.open("rb") as stream:
+                content = tomli.load(stream)
+        except (tomli.TOMLDecodeError, UnicodeDecodeError) as error:
             content = {}
             self._violations.append(str(error))
         else:
